@@ -1,5 +1,6 @@
 import time
 import json
+from datetime import datetime, timedelta
 
 from remote_config.validator import validate_feature, validate_cluster
 
@@ -46,13 +47,14 @@ class RemoteConfig():
         self.feature_job_id = None
 
     def start(self, start_sched=True):
+        if self.sched:
+            self.stop()
         job_time = str(time.time)
         self.cluster_job_id = 'cluster_{}'.format(job_time)
         self.feature_job_id = 'feature_{}'.format(job_time)
         self.sched = BackgroundScheduler(daemon=True)
-        from datetime import datetime
         feature_trigger = OrTrigger(
-            [DateTrigger(),
+            [DateTrigger(datetime.now() + timedelta(seconds=10)),
              IntervalTrigger(minutes=self.feature_minute)])
         cluster_trigger = OrTrigger(
             [DateTrigger(),
