@@ -8,10 +8,15 @@ def feature_list(self, path):
     return [u'general/feature-toggle/google-merchant']
 
 def feature_data(self, key):
-    return {u'default': False, u'clusters': [u'general/clusters/cluster-google-merchant'], u'enable': True}
+    return {
+        u'default': False,
+        u'clusters': [u'general/clusters/cluster-google-merchant'],
+        u'enable': True}
 
 def invalid_feature_data(self, key):
-    return {u'clusters': [u'general/clusters/cluster-google-merchant'], u'enable': True}
+    return {
+        u'clusters': [u'general/clusters/cluster-google-merchant'],
+        u'enable': True}
 
 def invalid_cluster_data(self, key):
     return {u'ids': ["123", 456]}
@@ -32,4 +37,10 @@ def cache_update_cluster_data(self, key):
     if 'cluster' in key :
         return {u'ids': [124]}
     else:
-        return feature_data(self, key)
\ No newline at end of file
+        return feature_data(self, key)
+
+def cache_update_feature_cluster_data(self, key):
+    if 'cluster' in key :
+        return {u'ids': [124]}
+    else:
+       return {u'default': False, u'clusters': [u'general/clusters/cluster-google-merchant'], u'enable': False}
\ No newline at end of file
